Learn R Programming

testthat (version 0.3)

test_package: Run all tests in an installed package...

Description

Run all tests in an installed package

Usage

test_package(package, reporter="summary")

Arguments

package
package name
reporter
reporter to use

Details

Test are run in an environment that inherits from the package environment so that tests can access non-exported functions and variables.

Examples

Run this code
test_package("testthat")

Run the code above in your browser using DataLab